==> openGion8.0.1.1_verup.zip: META-INF/resources/jsp/common/scrollBar2.js <==
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.findInternal=function(a,h,g){a instanceof String&&(a=String(a));for(var c=a.length,b=0;b<c;b++){var d=a[b];if(h.call(g,d,b,a))return{i:b,v:d}}return{i:-1,v:void 0}};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;
$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,h,g){if(a==Array.prototype||a==Object.prototype)return a;a[h]=g.value;return a};$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var h=0;h<a.length;++h){var g=a[h];if(g&&g.Math==Math)return g}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);
$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,h){var g=$jscomp.propertyToPolyfillSymbol[h];if(null==g)return a[h];g=a[g];return void 0!==g?g:a[h]};
$jscomp.polyfill=function(a,h,g,c){h&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,h,g,c):$jscomp.polyfillUnisolated(a,h,g,c))};$jscomp.polyfillUnisolated=function(a,h,g,c){g=$jscomp.global;a=a.split(".");for(c=0;c<a.length-1;c++){var b=a[c];if(!(b in g))return;g=g[b]}a=a[a.length-1];c=g[a];h=h(c);h!=c&&null!=h&&$jscomp.defineProperty(g,a,{configurable:!0,writable:!0,value:h})};
$jscomp.polyfillIsolated=function(a,h,g,c){var b=a.split(".");a=1===b.length;c=b[0];c=!a&&c in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var d=0;d<b.length-1;d++){var e=b[d];if(!(e in c))return;c=c[e]}b=b[b.length-1];g=$jscomp.IS_SYMBOL_NATIVE&&"es6"===g?c[b]:null;h=h(g);null!=h&&(a?$jscomp.defineProperty($jscomp.polyfills,b,{configurable:!0,writable:!0,value:h}):h!==g&&(void 0===$jscomp.propertyToPolyfillSymbol[b]&&(g=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[b]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(b):$jscomp.POLYFILL_PREFIX+g+"$"+b),$jscomp.defineProperty(c,$jscomp.propertyToPolyfillSymbol[b],{configurable:!0,writable:!0,value:h})))};$jscomp.polyfill("Array.prototype.find",function(a){return a?a:function(h,g){return $jscomp.findInternal(this,h,g).v}},"es6","es3");
function scrollBar2(a){alert("Old Script Error!!\ncustom/query_info.jsp,custom/result_info.jsp Please delete the following part.\n<script>Tag(Header fix and Focus) , BODY onLoad and oncontextmenu Attribute. scrollBar2(...)")}function AdjustScroll2(a){alert("Old Script Error!!\ncustom/query_info.jsp,custom/result_info.jsp Please delete the following part.\n<script>Tag(Header fix and Focus) , BODY onLoad and oncontextmenu Attribute. AdjustScroll2(...)")}function SetScrollHeader(a){}
(function(a){a.hgrid=a.hgrid||{};a.hgrid.defaults={sGantBody:"GantBody",sViewTable:"viewTable",sGridList:"GridList",sInAdjusting:"__bInAdjusting"};a.hgrid.load=function(c){var b=a("div > div > div > div > table.viewTable");if(0==a("body").width()||100==a("body").width())setTimeout(function(){a.hgrid.load(c)},1);else{var d=a("#"+a.hgrid.defaults.sGantBody+":first");a(window).data("gantBody",d);0<d.length&&2==b.length&&d.heightReset();b.each(function(e){g(a(this))});b.hybsGrid().adjustSB();focus2&&
focus2()}};a.hgrid.resize=function(c){a(this).data(a.hgrid.defaults.sInAdjusting)||(a(this).data(a.hgrid.defaults.sInAdjusting,!0),setTimeout(function(){var b=a.hgrid.defaults.sGridList;(b=a(window).data(b))&&a.each(b,function(){a(this.oTab).adjustSB()});a(window).data(a.hgrid.defaults.sInAdjusting,!1)},100))};a.hgrid.unload=function(c){c=a.hgrid.defaults.sGridList;var b=a(this).data(c);b&&(a.each(b,function(){this.oTab.grid=this.oTab.p=null}),b.length=0);a(this).removeData(c);a.hgrid=null};a(window).unbind("load.hgrid").bind("load.hgrid",
a.hgrid.load).unbind("resize.hgrid").bind("resize.hgrid",a.hgrid.resize).unbind("unload.hgrid").bind("unload.hgrid",a.hgrid.unload);var h=function(){var c;return function(){var b;if(!(b=c)){b=a('<div style="width:50px;height:50px;overflow:hidden;position:absolute;top:-200px;left:-200px;"><div style="height:100px;"></div>');a("body").append(b);var d=a("div",b).innerWidth();b.css("overflow-y","scroll");var e=a("div",b).innerWidth();0==d-e&&(e=d-17);a(b).remove();b=c=d-e}return b}}(),g=function(c){if(!c.data("cache")){var b=
a.browser.msie?!0:!1;c.parent().attr("id","divHide2").css({width:"10000em"});var d=[],e=a("thead:first",c),f=a("tr th",e);c.data("thead",e);c.data("trTh",f);f.each(function(q){d[q]=b?a(this).innerWidth():a(this).width()});c.data("thw",d);e=a.hybs.getHybsTr(c.find("tbody tr:first"));c.data("firstTr",e);f=b?e.outerHeight()||e.innerHeight():e.height();c.data("trh",f);var u=[],n=[];e=a("td",e);c.data("firstTrTd",e);e.each(function(q){0<a(this).find(".h_evElm").length&&("true"==a(this).attr("wa")&&a(this).css("width",
"auto"),"true"==a(this).attr("ha")&&a(this).css("height","auto"),"auto"==a(this).css("width")&&a(this).attr("wa","true"),"auto"==a(this).css("height")&&a(this).attr("ha","true"));u[q]=b?a(this).innerWidth():a(this).width();n[q]=a(this).height()});c.data("tdw",u);c.data("tdh",n);c.data("cache",!0)}};a.fn.heightReset=function(c){p=a.extend(!0,{},a.hgrid.defaults,c||{});return this.each(function(){var b=a("table."+p.sViewTable,this),d=b.get(0);b=b.get(1);var e=d.rows,f=b.rows,u=d.rows.length,n=d.tHead.rows.length;
for(k=0;k<n;k++){var q=Math.max(d.rows[k].offsetHeight,b.rows[k].offsetHeight);e[k].style.height=f[k].style.height=q+"px"}q=0;var k;for(k=n;k<u&&k<n+5;k++)q=Math.max(q,Math.max(e[k].offsetHeight,f[k].offsetHeight));for(k=n;k<u;k++)e[k].style.height=f[k].style.height=q+"px"})};a.fn.hybsGrid=function(c){c=a.extend(!0,{selrow:null,multiselect:!1,multikey:!1,nHoriExtra:16,nVertExtra:10,nMinLimit:50,nWidthScroll:h(),bX1VScroll:!1,bX2VScroll:!0},a.hgrid.defaults,c||{});var b={scrollGrid:function(){var d=
this.bDiv.scrollTop;this.hDiv.scrollLeft=this.bDiv.scrollLeft;if(this.oPrev){var e=this.oPrev.grid.bDiv;d!=e.scrollTop&&(e.scrollTop=d)}this.oNext&&(e=this.oNext.grid.bDiv,d!=e.scrollTop&&(e.scrollTop=d))}};a.fn.adjustSB=function(d){return this.each(function(){if(this.grid){"boolean"!=typeof d&&(d=!0);var e=a(this);var f=this.grid.hTable.parentNode;f.style.width&&(f.style.width=this.grid.hTable.offsetWidth+"px");f=this.grid.bHide;var u=a("thead:first",this);var n=u.outerHeight()+2*u[0].offsetTop;
f.style.width=e.outerWidth()+"px";f.style.height=e.outerHeight()-n+"px";f.scrollTop=n;for(var q=0,k=0;;){n=a(window).width();var v=a(window).height();e=a(this.grid.bDiv);var r=e.offset();var z=this.grid.oNext;var m=this.grid.oPrev;n=Math.max(n-Math.ceil(r.left)-this.p.nHoriExtra,this.p.nMinLimit);v=Math.max(v-Math.ceil(r.top)-this.p.nVertExtra,this.p.nMinLimit);n=this.p.width?0>this.p.width.indexOf("%")?parseInt(this.p.width,10):n*(parseInt(this.p.width,10)/100):n;v=this.p.height?0>this.p.height.indexOf("%")?
parseInt(this.p.height,10):v*(parseInt(this.p.height,10)/100):v;if(n<=q&&v<=k)break;var x=this.offsetWidth,y=f.offsetHeight;q=n;k=v;var w=q-x;var l=k-y;var t=0>w;r=0>l;var A;var B=A=!1;!t&&this.p.nWidthScroll>w&&(B=r||this.p.nWidthScroll>l);!r&&this.p.nWidthScroll>l&&(A=t||this.p.nWidthScroll>w);m&&m.grid.bHoriScroll&&(B=!1);B&&(t=!0);A&&(r=!0);z&&!this.p.bX1VScroll&&(r=!1);z=t?"scroll":"hidden";w=r?"scroll":"hidden";q=Math.min(q,x+(r?this.p.nWidthScroll:0));k=Math.min(k,y+(t?this.p.nWidthScroll:
0));this.grid.bHoriScroll=t;this.grid.bVertScroll=r;this.grid.width=q;this.grid.height=k;m&&(t=k-(t?this.p.nWidthScroll:0)+(m.grid.bHoriScroll?this.p.nWidthScroll:0),t!=m.grid.height&&(m.grid.height=t,x=m.grid.hDiv.offsetHeight,a(m.grid.bDiv).css("height",t+"px").parent().css({height:t+x+"px"})));a(this.grid.hDiv).width(q-(r?this.p.nWidthScroll:0));this.grid.firstRowHeight&&(m=this.grid.firstRowHeight,this.grid.firstRowHeight=null,a(this.grid.hDiv).height(this.grid.hDiv.offsetHeight-m));m=this.grid.hDiv.offsetHeight;
e.css({width:q+"px",height:k+"px","overflow-x":z,"overflow-y":w}).parent().css({height:k+m+"px",width:q+"px"});a.browser.msie&&7>parseInt(a.browser.version,10)&&u[0]&&(u[0].style.padding=u[0].currentStyle.padding);q=n;k=v}this.grid.scrollGrid()}})};return this.each(function(d){if("divHide"==this.parentNode.id||"divHide2"==this.parentNode.id){var e=this,f=a(e),u=a.browser.msie?!0:!1;d=a.extend(!0,{},b);var n=a.extend(!0,{},c),q=n.colModel=[];g(f);var k=!1;f.data("trTh").each(function(l){var t=a(this),
A=t.attr("field")||t.text();u&&1<t.attr("colSpan")&&(k=!0);q[l]=u?{name:A,index:A,width:f.data("thw")[l],colspan:t.attr("colSpan")}:{name:A,index:A,width:f.data("thw")[l]}});var v=!1,r=f.data("firstTr"),z=a(window).data("gantBody");0<z.length?v=!0:k&&r[0]&&f.data("firstTrTd").each(function(l){if(!q[l]||!q[l].colspan||a(this).attr("colSpan")!=q[l].colspan)return v=!0,!1});f.addClass("scroll");var m=e.parentNode;d.bHide=e.parentNode;d.bDiv=d.bHide.parentNode;(m=f.parents("#divPos")[0])&&a.each(["width",
"height"],function(){e.p&&e.p[this]?n[this]=e.p[this]:m.style[this]&&(n[this]=m.style[this],m.style[this]="auto")});a.each(n.colModel,function(l){"undefined"==typeof this.width&&(this.width=150)});var x=f.data("thead").get(0);f.data("trTh").each(function(l){"true"==a(this).attr("plusone")?a(this).css("width",n.colModel[l].width+"px"):(a(this).css("width",n.colModel[l].width+1+"px"),a(this).attr("plusone","true"))});d.hTable=document.createElement("table");var y=a(d.hTable);y.addClass(f.attr("class")).css({margin:"0px"});
a.each("cellspacing cellpadding border bordercolor frame rules".split(" "),function(l,t){f.attr(t)&&y.attr(t,f.attr(t))});y.attr("id","headerTable");f.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","").removeClass("visihidden")});m=x;x=a("#header",f);var w=[];for(a("input,select,textarea",x).each(function(l){"checkbox"==a(this).attr("type")?a(this).attr("checked")?w[l]="1":w[l]="0":w[l]=a(this).val()});m;)y.prepend(a(m).clone(!0)),m=m.previousSibling;
x=a(y).find("#header");a("input,select,textarea",x).each(function(l){"checkbox"==a(this).attr("type")?"1"==w[l]&&a(this).attr("checked",!0):a(this).val(w[l])});v&&r&&r[0]&&(d.firstRowHeight=f.data("trh")+1,a("td",r).each(function(l){a(this).css("width",f.data("tdw")[l]+"px").css("height",f.data("tdh")[l]+"px")}),jTrCl=r.clone(),a("td",jTrCl).each(function(l){a(this).html(""==a(this).text()?"":" ").css("backgroundColor","transparent")}),jAddTo=jTrCl.is("tr")?a(document.createElement("tbody")).appendTo(y):
y,jAddTo.append(jTrCl));d.hDiv=document.createElement("div");a(d.hDiv).attr("class","hGrid-header").append(a('<div style="width:10000em;" />').append(d.hTable));f.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","999").addClass("visihidden")});"hGrid-header"==a(d.bDiv).prev().attr("class")&&a(d.bDiv).prev().remove();a(d.bDiv).before(d.hDiv);a(d.bDiv).scroll(function(l){(l=a("table:first",l.target)[0])&&l.grid&&l.grid.scrollGrid()});m=a(window).data(n.sGridList);
0<z.length&&m&&(r=m[m.length-1],r.oWrap===z[0]&&(r.oTab.grid.oNext=e,d.oPrev=r.oTab));m||(m=[]);m.push({oTab:e,oWrap:z[0]});a(window).data(n.sGridList,m);f.data("cache",!1);e.grid=d;e.p=n;e=f=m=z=d=n=null}})}})(jQuery);

==> openGion8.1.1.2_verup.zip: META-INF/resources/jsp/common/scrollBar2.js <==
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.findInternal=function(a,h,g){a instanceof String&&(a=String(a));for(var c=a.length,b=0;b<c;b++){var d=a[b];if(h.call(g,d,b,a))return{i:b,v:d}}return{i:-1,v:void 0}};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;
$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,h,g){if(a==Array.prototype||a==Object.prototype)return a;a[h]=g.value;return a};$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var h=0;h<a.length;++h){var g=a[h];if(g&&g.Math==Math)return g}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);
$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,h){var g=$jscomp.propertyToPolyfillSymbol[h];if(null==g)return a[h];g=a[g];return void 0!==g?g:a[h]};
$jscomp.polyfill=function(a,h,g,c){h&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,h,g,c):$jscomp.polyfillUnisolated(a,h,g,c))};$jscomp.polyfillUnisolated=function(a,h,g,c){g=$jscomp.global;a=a.split(".");for(c=0;c<a.length-1;c++){var b=a[c];if(!(b in g))return;g=g[b]}a=a[a.length-1];c=g[a];h=h(c);h!=c&&null!=h&&$jscomp.defineProperty(g,a,{configurable:!0,writable:!0,value:h})};
$jscomp.polyfillIsolated=function(a,h,g,c){var b=a.split(".");a=1===b.length;c=b[0];c=!a&&c in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var d=0;d<b.length-1;d++){var e=b[d];if(!(e in c))return;c=c[e]}b=b[b.length-1];g=$jscomp.IS_SYMBOL_NATIVE&&"es6"===g?c[b]:null;h=h(g);null!=h&&(a?$jscomp.defineProperty($jscomp.polyfills,b,{configurable:!0,writable:!0,value:h}):h!==g&&(void 0===$jscomp.propertyToPolyfillSymbol[b]&&(g=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[b]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(b):$jscomp.POLYFILL_PREFIX+g+"$"+b),$jscomp.defineProperty(c,$jscomp.propertyToPolyfillSymbol[b],{configurable:!0,writable:!0,value:h})))};$jscomp.polyfill("Array.prototype.find",function(a){return a?a:function(h,g){return $jscomp.findInternal(this,h,g).v}},"es6","es3");
function scrollBar2(a){alert("Old Script Error!!\ncustom/query_info.jsp,custom/result_info.jsp Please delete the following part.\n<script>Tag(Header fix and Focus) , BODY onLoad and oncontextmenu Attribute. scrollBar2(...)")}function SetScrollHeader(a){}
(function(a){a.hgrid=a.hgrid||{};a.hgrid.defaults={sGantBody:"GantBody",sViewTable:"viewTable",sGridList:"GridList",sInAdjusting:"__bInAdjusting"};a.hgrid.load=function(c){var b=a("div > div > div > div > table.viewTable");if(0==a("body").width()||100==a("body").width())setTimeout(function(){a.hgrid.load(c)},1);else{var d=a("#"+a.hgrid.defaults.sGantBody+":first");a(window).data("gantBody",d);0<d.length&&2==b.length&&d.heightReset();b.each(function(e){g(a(this))});b.hybsGrid().adjustSB();focus2&&
focus2()}};a.hgrid.resize=function(c){a(this).data(a.hgrid.defaults.sInAdjusting)||(a(this).data(a.hgrid.defaults.sInAdjusting,!0),setTimeout(function(){var b=a.hgrid.defaults.sGridList;(b=a(window).data(b))&&a.each(b,function(){a(this.oTab).adjustSB()});a(window).data(a.hgrid.defaults.sInAdjusting,!1)},100))};a.hgrid.unload=function(c){c=a.hgrid.defaults.sGridList;var b=a(this).data(c);b&&(a.each(b,function(){this.oTab.grid=this.oTab.p=null}),b.length=0);a(this).removeData(c);a.hgrid=null};a(window).unbind("load.hgrid").bind("load.hgrid",
a.hgrid.load).unbind("resize.hgrid").bind("resize.hgrid",a.hgrid.resize).unbind("unload.hgrid").bind("unload.hgrid",a.hgrid.unload);var h=function(){var c;return function(){var b;if(!(b=c)){b=a('<div style="width:50px;height:50px;overflow:hidden;position:absolute;top:-200px;left:-200px;"><div style="height:100px;"></div>');a("body").append(b);var d=a("div",b).innerWidth();b.css("overflow-y","scroll");var e=a("div",b).innerWidth();0==d-e&&(e=d-17);a(b).remove();b=c=d-e}return b}}(),g=function(c){if(!c.data("cache")){var b=
a.browser.msie?!0:!1;c.parent().attr("id","divHide2").css({width:"10000em"});var d=[],e=a("thead:first",c),f=a("tr th",e);c.data("thead",e);c.data("trTh",f);f.each(function(q){d[q]=b?a(this).innerWidth():a(this).width()});c.data("thw",d);e=a.hybs.getHybsTr(c.find("tbody tr:first"));c.data("firstTr",e);f=b?e.outerHeight()||e.innerHeight():e.height();c.data("trh",f);var u=[],n=[];e=a("td",e);c.data("firstTrTd",e);e.each(function(q){0<a(this).find(".h_evElm").length&&("true"==a(this).attr("wa")&&a(this).css("width",
"auto"),"true"==a(this).attr("ha")&&a(this).css("height","auto"),"auto"==a(this).css("width")&&a(this).attr("wa","true"),"auto"==a(this).css("height")&&a(this).attr("ha","true"));u[q]=b?a(this).innerWidth():a(this).width();n[q]=a(this).height()});c.data("tdw",u);c.data("tdh",n);c.data("cache",!0)}};a.fn.heightReset=function(c){p=a.extend(!0,{},a.hgrid.defaults,c||{});return this.each(function(){var b=a("table."+p.sViewTable,this),d=b.get(0);b=b.get(1);var e=d.rows,f=b.rows,u=d.rows.length,n=d.tHead.rows.length;
for(k=0;k<n;k++){var q=Math.max(d.rows[k].offsetHeight,b.rows[k].offsetHeight);e[k].style.height=f[k].style.height=q+"px"}q=0;var k;for(k=n;k<u&&k<n+5;k++)q=Math.max(q,Math.max(e[k].offsetHeight,f[k].offsetHeight));for(k=n;k<u;k++)e[k].style.height=f[k].style.height=q+"px"})};a.fn.hybsGrid=function(c){c=a.extend(!0,{selrow:null,multiselect:!1,multikey:!1,nHoriExtra:16,nVertExtra:10,nMinLimit:50,nWidthScroll:h(),bX1VScroll:!1,bX2VScroll:!0},a.hgrid.defaults,c||{});var b={scrollGrid:function(){var d=
this.bDiv.scrollTop;this.hDiv.scrollLeft=this.bDiv.scrollLeft;if(this.oPrev){var e=this.oPrev.grid.bDiv;d!=e.scrollTop&&(e.scrollTop=d)}this.oNext&&(e=this.oNext.grid.bDiv,d!=e.scrollTop&&(e.scrollTop=d))}};a.fn.adjustSB=function(d){return this.each(function(){if(this.grid){"boolean"!=typeof d&&(d=!0);var e=a(this);var f=this.grid.hTable.parentNode;f.style.width&&(f.style.width=this.grid.hTable.offsetWidth+"px");f=this.grid.bHide;var u=a("thead:first",this);var n=u.outerHeight()+2*u[0].offsetTop;
f.style.width=e.outerWidth()+"px";f.style.height=e.outerHeight()-n+"px";f.scrollTop=n;for(var q=0,k=0;;){n=a(window).width();var v=a(window).height();e=a(this.grid.bDiv);var r=e.offset();var z=this.grid.oNext;var m=this.grid.oPrev;n=Math.max(n-Math.ceil(r.left)-this.p.nHoriExtra,this.p.nMinLimit);v=Math.max(v-Math.ceil(r.top)-this.p.nVertExtra,this.p.nMinLimit);n=this.p.width?0>this.p.width.indexOf("%")?parseInt(this.p.width,10):n*(parseInt(this.p.width,10)/100):n;v=this.p.height?0>this.p.height.indexOf("%")?
parseInt(this.p.height,10):v*(parseInt(this.p.height,10)/100):v;if(n<=q&&v<=k)break;var x=this.offsetWidth,y=f.offsetHeight;q=n;k=v;var w=q-x;var l=k-y;var t=0>w;r=0>l;var A;var B=A=!1;!t&&this.p.nWidthScroll>w&&(B=r||this.p.nWidthScroll>l);!r&&this.p.nWidthScroll>l&&(A=t||this.p.nWidthScroll>w);m&&m.grid.bHoriScroll&&(B=!1);B&&(t=!0);A&&(r=!0);z&&!this.p.bX1VScroll&&(r=!1);z=t?"scroll":"hidden";w=r?"scroll":"hidden";q=Math.min(q,x+(r?this.p.nWidthScroll:0));k=Math.min(k,y+(t?this.p.nWidthScroll:
0));this.grid.bHoriScroll=t;this.grid.bVertScroll=r;this.grid.width=q;this.grid.height=k;m&&(t=k-(t?this.p.nWidthScroll:0)+(m.grid.bHoriScroll?this.p.nWidthScroll:0),t!=m.grid.height&&(m.grid.height=t,x=m.grid.hDiv.offsetHeight,a(m.grid.bDiv).css("height",t+"px").parent().css({height:t+x+"px"})));a(this.grid.hDiv).width(q-(r?this.p.nWidthScroll:0));this.grid.firstRowHeight&&(m=this.grid.firstRowHeight,this.grid.firstRowHeight=null,a(this.grid.hDiv).height(this.grid.hDiv.offsetHeight-m));m=this.grid.hDiv.offsetHeight;
e.css({width:q+"px",height:k+"px","overflow-x":z,"overflow-y":w}).parent().css({height:k+m+"px",width:q+"px"});a.browser.msie&&7>parseInt(a.browser.version,10)&&u[0]&&(u[0].style.padding=u[0].currentStyle.padding);q=n;k=v}this.grid.scrollGrid()}})};return this.each(function(d){if("divHide"==this.parentNode.id||"divHide2"==this.parentNode.id){var e=this,f=a(e),u=a.browser.msie?!0:!1;d=a.extend(!0,{},b);var n=a.extend(!0,{},c),q=n.colModel=[];g(f);var k=!1;f.data("trTh").each(function(l){var t=a(this),
A=t.attr("field")||t.text();u&&1<t.attr("colSpan")&&(k=!0);q[l]=u?{name:A,index:A,width:f.data("thw")[l],colspan:t.attr("colSpan")}:{name:A,index:A,width:f.data("thw")[l]}});var v=!1,r=f.data("firstTr"),z=a(window).data("gantBody");0<z.length?v=!0:k&&r[0]&&f.data("firstTrTd").each(function(l){if(!q[l]||!q[l].colspan||a(this).attr("colSpan")!=q[l].colspan)return v=!0,!1});f.addClass("scroll");var m=e.parentNode;d.bHide=e.parentNode;d.bDiv=d.bHide.parentNode;(m=f.parents("#divPos")[0])&&a.each(["width",
"height"],function(){e.p&&e.p[this]?n[this]=e.p[this]:m.style[this]&&(n[this]=m.style[this],m.style[this]="auto")});a.each(n.colModel,function(l){"undefined"==typeof this.width&&(this.width=150)});var x=f.data("thead").get(0);f.data("trTh").each(function(l){"true"==a(this).attr("plusone")?a(this).css("width",n.colModel[l].width+"px"):(a(this).css("width",n.colModel[l].width+1+"px"),a(this).attr("plusone","true"))});d.hTable=document.createElement("table");var y=a(d.hTable);y.addClass(f.attr("class")).css({margin:"0px"});
a.each("cellspacing cellpadding border bordercolor frame rules".split(" "),function(l,t){f.attr(t)&&y.attr(t,f.attr(t))});y.attr("id","headerTable");f.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","").removeClass("visihidden")});m=x;x=a("#header",f);var w=[];for(a("input,select,textarea",x).each(function(l){"checkbox"==a(this).attr("type")?a(this).attr("checked")?w[l]="1":w[l]="0":w[l]=a(this).val()});m;)y.prepend(a(m).clone(!0)),m=m.previousSibling;
x=a(y).find("#header");a("input,select,textarea",x).each(function(l){"checkbox"==a(this).attr("type")?"1"==w[l]&&a(this).attr("checked",!0):a(this).val(w[l])});v&&r&&r[0]&&(d.firstRowHeight=f.data("trh")+1,a("td",r).each(function(l){a(this).css("width",f.data("tdw")[l]+"px").css("height",f.data("tdh")[l]+"px")}),jTrCl=r.clone(),a("td",jTrCl).each(function(l){a(this).html(""==a(this).text()?"":" ").css("backgroundColor","transparent")}),jAddTo=jTrCl.is("tr")?a(document.createElement("tbody")).appendTo(y):
y,jAddTo.append(jTrCl));d.hDiv=document.createElement("div");a(d.hDiv).attr("class","hGrid-header").append(a('<div style="width:10000em;" />').append(d.hTable));f.data("trTh").find("a,input,select,textarea,span,button,img").each(function(){a(this).attr("tabindex","999").addClass("visihidden")});"hGrid-header"==a(d.bDiv).prev().attr("class")&&a(d.bDiv).prev().remove();a(d.bDiv).before(d.hDiv);a(d.bDiv).scroll(function(l){(l=a("table:first",l.target)[0])&&l.grid&&l.grid.scrollGrid()});m=a(window).data(n.sGridList);
0<z.length&&m&&(r=m[m.length-1],r.oWrap===z[0]&&(r.oTab.grid.oNext=e,d.oPrev=r.oTab));m||(m=[]);m.push({oTab:e,oWrap:z[0]});a(window).data(n.sGridList,m);f.data("cache",!1);e.grid=d;e.p=n;e=f=m=z=d=n=null}})}})(jQuery);
